Learn R Programming

edina (version 0.1.1)

edina-package: edina: Bayesian Estimation of an Exploratory Deterministic Input, Noisy and Gate Model

Description

Perform a Bayesian estimation of the exploratory deterministic input, noisy and gate (EDINA) cognitive diagnostic model described by Chen et al. (2018) <doi:10.1007/s11336-017-9579-4>.

Arguments

Author

Maintainer: James Joseph Balamuta balamut2@illinois.edu (ORCID) [copyright holder]

Authors:

See Also