Provide a more detailed view inside of edina model object.
# S3 method for edina
summary(object, alpha = 0.05, ...)A summary object that includes everything in the original edina() object
and:
model_fit: Matrix of model fit summary statistics.
alpha: Alpha-value used to compute PPP()s.
An edina object
Defining region to indicate the level of extremeness the data must before the model is problematic.
Not used.